#
# spec file for package python-traitlets
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-traitlets
Version:        4.3.3
Release:        lp152.2.1
Summary:        Traitlets Python config system
License:        BSD-3-Clause
URL:            https://github.com/ipython/traitlets
Source:         https://files.pythonhosted.org/packages/source/t/traitlets/traitlets-%{version}.tar.gz
BuildRequires:  %{python_module decorator}
BuildRequires:  %{python_module ipython_genutils}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-decorator
Requires:       python-ipython_genutils
Requires:       python-six
BuildArch:      noarch
%if %{with python2}
BuildRequires:  python-enum34
BuildRequires:  python-mock
%endif
%ifpython2
Requires:       python-enum34
%endif
%python_subpackages

%description
A configuration system for Python applications.

%prep
%setup -q -n traitlets-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
pushd docs
%pytest ../traitlets/tests

%files %{python_files}
%doc README.md
%doc examples/
%license COPYING.md
%{python_sitelib}/traitlets/
%{python_sitelib}/traitlets-%{version}-py*.egg-info

%changelog
* Thu Mar 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to version 4.3.3
  * Adds Application.loaded_config_files property for accessing
    config files that have been loaded and makes the property
    idempotent on multiple loads.
* Wed Jul  5 2017 tbechtold@suse.com
- Add missing python-six BuildRequires
* Wed Jul  5 2017 tbechtold@suse.com
- Add missing python-six Requires
* Fri Apr 14 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to 4.3.2
  * using :meth:`_traitname_default()` without the ``@default``
    decorator is no longer deprecated.
  * Passing ``config=True`` in traitlets constructors is no longer
    deprecated.
- Update to 4.3.1
  * Compatibility fix for Python 3.6a1
  * Fix bug in Application.classes getting extra entries when
    multiple Applications are instantiated in the same process.
- Update to 4.3.0
  * Improve the generated config file output.
  * Allow TRAITLETS_APPLICATION_RAISE_CONFIG_FILE_ERROR env to
    override :attr:`Application.raise_config_file_errors`,
    so that config file errors can result in exiting immediately.
  * Avoid using root logger. If no application logger is registered,
    the ``'traitlets'`` logger will be used instead of the root
    logger.
  * Change/Validation arguments are now Bunch objects, allowing
    attribute-access, in addition to dictionary access.
  * Reduce number of common deprecation messages in certain cases.
  * Ensure command-line options always have higher priority than
    config files.
  * Add bounds on numeric traits.
  * Improves various error messages.
- Update to 4.2.2
  * Partially revert a change in 4.1 that prevented IPython's
    command-line options from taking priority over config files.
- Update to 4.2.1
  * Demotes warning about unused arguments in ``HasTraits.__init__``
    introduced in 4.2.0 to DeprecationWarning.
- Update to 4.2.0
  * :class:`JSONFileConfigLoader` can be used as a context manager
    for updating configuration.
  * If a value in config does not map onto a configurable trait,
    a message is displayed that the value will have no effect.
  * Unused arguments are passed to ``super()`` in
    ``HasTraits.__init__``, improving support for multiple
    inheritance.
  * Various bugfixes and improvements in the new API introduced
    in 4.1.
  * Application subclasses may specify
    ``raise_config_file_errors = True``
    to exit on failure to load config files,
    instead of the default of logging the failures.
- Update to 4.1
  * Decorators are used, rather than magic method names, for
    registering trait-related methods. See :doc:`using_traitlets`
    and :doc:`migration` for more info.
  * Deprecate ``Trait(config=True)`` in favor of
    ``Trait().tag(config=True)``. In general, metadata is added
    via ``tag`` instead of the constructor.
  * Trait attributes initialized with ``read_only=True`` can only
    be set with the ``set_trait`` method.
    Attempts to directly modify a read-only trait attribute raises
    a ``TraitError``.
  * The directional link now takes an optional `transform`
    attribute allowing the modification of the value.
  * Various fixes and improvements to config-file generation
    (fixed ordering, Undefined showing up, etc.)
  * Warn on unrecognized traits that aren't configurable, to avoid
    silently ignoring mistyped config.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to version
* Fri Aug 14 2015 toddrme2178@gmail.com
- Fix package naming consistency
* Thu Aug 13 2015 toddrme2178@gmail.com
- Update dependency names
* Tue Jul 21 2015 toddrme2178@gmail.com
- Initial version
